@@ -1,3 +1,3 @@
 #!/bin/sh
 # $1 = union directory
-chown -R guest.users $1/home/guest
+chown -R guest:users $1/home/guest
